--RESOURCES/SETTINGS
love.graphics.setBackgroundColor (0,0.4,0)
love.graphics.setDefaultFilter ('nearest','nearest')

--repeating background
local W,H = love.graphics.getDimensions()
local bgImage = love.graphics.newImage ('images/grass.png')
local bgQuad = love.graphics.newQuad (0,0,W,H,bgImage:getDimensions())
bgImage:setWrap('repeat','repeat')

local sphere = love.graphics.newImage ('images/sphere.png')
local sphereShadow = love.graphics.newImage ('images/sphereShadow.png')

local shadowCanvas = love.graphics.newCanvas()
local mainCanvas = love.graphics.newCanvas()
local shadowTrans = 0.4 --transparency of shadows

local object_shader = love.graphics.newShader([[
uniform Image MainTex;

void effect()
{
	vec4 real_color = Texel(MainTex, VaryingTexCoord.xy) * VaryingColor;
	love_Canvases[0] = real_color; // Draw normally to main canvas.
	love_Canvases[1] = vec4(1.0, 1.0, 1.0, real_color.a); // Draw white to shadow canvas.
}
]])

local shadow_shader = love.graphics.newShader([[
vec4 effect(vec4 color, Image tex, vec2 texture_coords, vec2 screen_coords)
{
	// A black and white texture, only need one channel. Use inverse so black == opaque & white == transparent.
	float shadow = 1.0 - Texel(tex, texture_coords).r;
	return color * shadow;
}
]])

function love.draw()
	local zoom = 2 --zoom in so it's easier to see

	love.graphics.setCanvas(mainCanvas)
	love.graphics.clear()
	love.graphics.setCanvas(shadowCanvas)
	love.graphics.clear(1, 1, 1, 1)

	--draw floor shadows
	love.graphics.setColor(0,0,0,1)
	love.graphics.draw(sphereShadow,100,112)

	--draw objects with multi-canvas shader
	love.graphics.setCanvas(mainCanvas, shadowCanvas)
	love.graphics.setShader(object_shader)
	love.graphics.setColor(1,1,1,1)
	love.graphics.draw(sphere,100,100)
	love.graphics.setShader()

	--draw top shadows
	love.graphics.setCanvas(shadowCanvas)
	local mx, my = love.mouse.getPosition()
	love.graphics.setColor(0,0,0,1)
	love.graphics.draw(sphereShadow,mx/zoom-19,my/zoom-19)--draw shadow at mouse x,y (with offset)
	love.graphics.draw(sphereShadow,mx/zoom-38,my/zoom-23)--draw another top shadow to make sure overlap works
	love.graphics.setCanvas()

	--draw stuff to screen
	love.graphics.push()
	love.graphics.scale(zoom)

	love.graphics.setColor(1,1,1,1)
	love.graphics.draw(bgImage,bgQuad,0,0) --draw repeating background

	love.graphics.draw(mainCanvas)

	love.graphics.setColor(0, 0, 0, shadowTrans)
	love.graphics.setShader(shadow_shader)
	love.graphics.draw(shadowCanvas)
	love.graphics.setShader()

	love.graphics.pop()
end
